<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Abhinav Tyagi <abhinavtyagi11@gmail.com>
 * @author yndesai@gmail.com
 */
$lang['unknown']               = 'अज्ञात';
$lang['date']                  = 'दिनांक:';
$lang['author']                = 'लेखक:';
$lang['error']                 = 'अज्ञात त्रुटि हुइ';
